@@ -1,5 +1,5 @@
 from .auth import set_nerd_compute_api_key, get_api_key
-from .storage import is_large_data, upload_nerd_cloud_storage, fetch_nerd_cloud_storage
+from .storage.storage import is_large_data, upload_nerd_cloud_storage, fetch_nerd_cloud_storage
 from .job import cancel_job, list_active_jobs, cancel_all_jobs
 from .compute import cloud_compute, process_error_response
 from .import_utils import extract_imports, _get_stdlib_modules, _extract_used_names, _filter_imports_by_usage
