@@ -191,6 +191,18 @@ def cloud_compute(cores=8, timeout=1800):
             def serialize_with_chunking(obj):
                 try:
                     # Special handling for large binary data that should go to S3 directly
+                    if isinstance(obj, dict) and "__nerd_data_reference" in obj:
+                        debug_print(f"Found reference object, serializing reference only")
+                        return {
+                            'type': 'bytes_reference',
+                            'value': {
+                                'data_reference': obj['__nerd_data_reference'],
+                                's3Uri': obj.get('__nerd_s3_uri', ''),
+                                'sizeMB': obj.get('__nerd_size_mb', '')
+                            }
+                        }
+                    
+                    # Special handling for very large binary data
                     if isinstance(obj, bytes) and len(obj) > 5 * 1024 * 1024:  # > 5MB
                         size_mb = len(obj) / (1024 * 1024)
                         debug_print(f"Large binary data detected: {size_mb:.2f} MB")
@@ -208,8 +220,8 @@ def cloud_compute(cores=8, timeout=1800):
                         }
 
                     # Standard serialization for everything else:
-                    # 1. Pickle the object to binary form
-                    pickled = pickle.dumps(obj)
+                    # 1. Pickle the object to binary form (use protocol 4 for compatibility)
+                    pickled = pickle.dumps(obj, protocol=4)
                     # 2. Compress the pickled data
                     compressed = zlib.compress(pickled)
                     # 3. Base64 encode the compressed data
