@@ -31,42 +31,23 @@ def resolve_references(obj):
                     print(f"Successfully retrieved data: {len(raw_data) / (1024 * 1024):.2f} MB")
                     
                     try:
-                        # First try to decompress then unpickle
+                        # First try to decompress then unpickle - use protocol 4 for compatibility
                         decompressed_data = zlib.decompress(raw_data)
                         unpickled_data = pickle.loads(decompressed_data)
                         print(f"Successfully unpickled data of type: {type(unpickled_data).__name__}")
-                        
-                        # Handle special cases for astronomy data
-                        
-                        # Case 1: Sparse catalog
-                        if isinstance(unpickled_data, dict) and 'sources' in unpickled_data and 'positions' in unpickled_data:
-                            print("Detected sparse catalog data structure")
-                            # No pre-processing needed - DataFrame creation happens in the function
-                            
-                        # Case 2: ML model
-                        elif isinstance(unpickled_data, dict) and 'model' in unpickled_data:
-                            print("Detected ML model data structure")
-                            # If the model is bytes, try to unpickle it
-                            if isinstance(unpickled_data['model'], bytes):
-                                try:
-                                    unpickled_data['model'] = pickle.loads(unpickled_data['model'])
-                                    print(f"Successfully unpickled model of type: {type(unpickled_data['model']).__name__}")
-                                except Exception as e:
-                                    print(f"Error unpickling model: {e}")
-                        
-                        # Case 3: HEALPix map
-                        elif isinstance(unpickled_data, dict) and 'pixels' in unpickled_data:
-                            print("Detected HEALPix map data structure")
-                            # Make sure we have pixel_values
-                            if 'pixel_values' not in unpickled_data:
-                                print("Adding pixel_values key with pixels data")
-                                unpickled_data['pixel_values'] = unpickled_data['pixels']
-                                
                         return unpickled_data
                         
                     except Exception as e:
                         print(f"Error processing data: {e}")
-                        return raw_data
+                        # Try alternate approaches for backwards compatibility
+                        try:
+                            # Try just unpickling directly
+                            direct_unpickled = pickle.loads(raw_data)
+                            print(f"Successfully unpickled raw data of type: {type(direct_unpickled).__name__}")
+                            return direct_unpickled
+                        except Exception as e2:
+                            print(f"Error unpickling raw data: {e2}")
+                            return raw_data
                     
                 except Exception as e:
                     print(f"Error retrieving data: {e}")
