@@ -1,10 +1,15 @@
 # This template handles the argument unpacking and execution of the function
 # For astronomy functions, use patched versions
 try:
+    # Add directory to path to ensure patch can be imported
+    import sys
+    import os
+    sys.path.append(os.path.dirname(os.path.abspath(__file__)))
+    
     from catalog_patch import process_sparse_catalog as patched_sparse_catalog
     print("Successfully imported patched sparse catalog function")
-except ImportError:
-    print("Patched sparse catalog function not available")
+except ImportError as e:
+    print(f"Patched sparse catalog function not available: {e}")
     patched_sparse_catalog = None
 
 # Unpack all the arguments
@@ -45,10 +50,31 @@ for key, arg_data in KWARGS_PLACEHOLDER.items():
 try:
     print(f"Starting cloud execution of FUNC_NAME_PLACEHOLDER...")
     
-    # Check if we need to use patched version for specific functions
-    if FUNC_NAME_PLACEHOLDER == "process_sparse_catalog" and patched_sparse_catalog is not None:
+    # Special handling for specific functions
+    if "process_sparse_catalog" in FUNC_NAME_PLACEHOLDER and patched_sparse_catalog is not None:
         print("Using patched version of process_sparse_catalog")
         result = patched_sparse_catalog(*args, **kwargs)
+    elif "evaluate_astronomy_model" in FUNC_NAME_PLACEHOLDER:
+        print("Special handling for astronomy model evaluation")
+        # Make sure the model is unpickled
+        if len(args) > 0 and isinstance(args[0], dict) and 'model' in args[0]:
+            if isinstance(args[0]['model'], bytes):
+                import pickle
+                print("Unpickling model from bytes")
+                try:
+                    args[0]['model'] = pickle.loads(args[0]['model'])
+                    print(f"Successfully unpickled model: {type(args[0]['model'])}")
+                except Exception as e:
+                    print(f"Error unpickling model: {e}")
+        result = auto_reference_wrapper(FUNC_NAME_PLACEHOLDER, args, kwargs)
+    elif "process_healpix_map" in FUNC_NAME_PLACEHOLDER:
+        print("Special handling for HEALPix map processing")
+        # Make sure pixel_values is set
+        if len(args) > 0 and isinstance(args[0], dict) and 'pixels' in args[0]:
+            if 'pixel_values' not in args[0]:
+                args[0]['pixel_values'] = args[0]['pixels']
+                print("Added pixel_values from pixels")
+        result = auto_reference_wrapper(FUNC_NAME_PLACEHOLDER, args, kwargs)
     else:
         # Use the standard function
         result = auto_reference_wrapper(FUNC_NAME_PLACEHOLDER, args, kwargs)
